@@ -343,7 +343,7 @@ class getter_trnDayStockPrice(baseGetter):
             brandCd = kwargs.get('brandCd')
             
             # html解析
-            html = self.wDriver.page_source.encode('utf-8')
+            html = element.parent.page_source
             bsSrc = BeautifulSoup(html, 'html.parser')
 
             # スクレイピング結果から改行ｺｰﾄﾞを除去
